@@ -110,11 +110,11 @@ _SEQDB = {
     '< CSI 2W'           : 'Ambiguous reporting(MinTTY): treat ambiguous width characters as double width',
     '< CSI ?c'           : 'DA1 Response',
     '< CSI ?1;0c'        : 'DA1 Response: VT100 with no options (could be WizConsole VT100 mode)',
-    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck)',
+    '< CSI ?1;2c'        : 'DA1 Response: VT100 with AVO (could be a VT102/rxvt/rxvt-unicode/konsole/kterm/mlterm/iTerm2/tmux/aterm/wterm/Terminal.app(Mac)/mrxvt/MinTTY/TeraTerm/ck/tty.js)',
     '< CSI ?1;6c'        : 'DA1 Response: VT100 with AVO and GPO (could be MacTerm)',
     '< CSI ?1;2;4;7c'    : 'DA1 Response: mlterm(3.1.7 or later) with Sixel/DRCS',
     '< CSI ?1;2;4c'      : 'DA1 Response: mlterm(3.1.7 or later) with DRCS',
-    '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft/Cathode)',
+    '< CSI ?6c'          : 'DA1 Response: VT102 (could be linux xvt/console/PuTTY/Terminal.app(GNUStep)/yaft/Cathode/tty.js(linux console mode))',
     '< CSI ?62c'         : 'DA1 Response: VT200 family (could be mosh/WizConsole VT200 mode)',
     '< CSI ?62;9;c'      : 'DA1 Response: VT200 family (could be gnome-terminal)',
     '< CSI ?64;1;2;6;9;15;21;22c': 'DA1 Response: VT400 family (could be xterm pl>=280)',
@@ -126,27 +126,30 @@ _SEQDB = {
     '< CSI >0;95;0c'     : 'DA2 Response: xterm patch#95 (could be tmux)',
     '< CSI >0;95;1c'     : 'DA2 Response: xterm patch#95 (could be avaliable mouse)',
     '< CSI >0;115;0c'    : 'DA2 Response: xterm patch#115 (could be Konsole)',
-    '< CSI >0;136;0c'    : 'DA2 Response: xterm patch#136 (could be PuTTY)',
+    '< CSI >0;136;0c'    : 'DA2 Response: xterm patch#136 (could be PuTTY or MinTTY v0.3)',
     '< CSI >0;270;0c'    : 'DA2 Response: VT100 (could be xterm patch#270)',
     '< CSI >0;271;0c'    : 'DA2 Response: VT100 (could be xterm patch#271)',
     '< CSI >0;272;0c'    : 'DA2 Response: VT100 (could be xterm patch#272)',
     '< CSI >0;273;0c'    : 'DA2 Response: VT100 (could be xterm patch#273)',
     '< CSI >0;274;0c'    : 'DA2 Response: VT100 (could be xterm patch#274)',
     '< CSI >0;275;0c'    : 'DA2 Response: VT100 (could be xterm patch#275)',
-    '< CSI >0;276;0c'    : 'DA2 Response: VT100 (could be xterm patch#276)',
+    '< CSI >0;276;0c'    : 'DA2 Response: VT100 (could be xterm patch#276 or tty.js)',
     '< CSI >0;277;0c'    : 'DA2 Response: VT100 (could be xterm patch#277 or tanasinn)',
     '< CSI >0;278;0c'    : 'DA2 Response: VT100 (could be xterm patch#278)',
     '< CSI >0;279;0c'    : 'DA2 Response: VT100 (could be xterm patch#279)',
     '< CSI >1;[2]c'      : 'DA2 Response: VT220, Pv=%s, keyboard type=%s',
     '< CSI >1;10;0c'     : 'DA2 Response: VT220 (could be mosh/WizConsole VT200 mode)',
     '< CSI >1;96;0c'     : 'DA2 Response: VT220 (could be mlterm)',
+    '< CSI >1;1115;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >1;2403;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >1;2802;0c'   : 'DA2 Response: VT220 (could be VTE, such as gnome-terminal)',
     '< CSI >2;[2]c'      : 'DA2 Response: VT240, Pv=%s, keyboard type=%s',
+    '< CSI >6;[2]c'      : 'DA2 Response: Haiku terminal, Pv=%s, keyboard type=%s',
     '< CSI >18;[2]c'     : 'DA2 Response: VT330, Pv=%s, keyboard type=%s',
     '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%s, keyboard type=%s',
     '< CSI >19;[2]c'     : 'DA2 Response: VT340, Pv=%s, keyboard type=%s',
     '< CSI >24;[2]c'     : 'DA2 Response: VT320, Pv=%s, keyboard type=%s',
+    '< CSI >28;[2]c'     : 'DA2 Response: DECTerm window, Pv=%s, keyboard type=%s',
     '< CSI >32;[2]c'     : 'DA2 Response: VT382, Pv=%s, keyboard type=%s',
     '< CSI >32;100;2c'   : 'DA2 Response: VT382 (could be TeraTerm)',
     '< CSI >32;277;2c'   : 'DA2 Response: VT382 (could be mouseterm-plus)',
@@ -181,9 +184,10 @@ _SEQDB = {
     '< CSI >83;40000;0c' : 'DA2 Response: could be GNU Screen 4.0.0',
     '< CSI >83;40001;0c' : 'DA2 Response: could be GNU Screen 4.0.1',
     '< CSI >83;40002;0c' : 'DA2 Response: could be GNU Screen 4.0.2',
-    '< CSI >83;40003;0c' : 'DA2 Response: could be GNU Screen 4.0.3',
+    '< CSI >83;40003;0c' : 'DA2 Response: could be GNU Screen 4.0.3 or tty.js(screen mode)',
     '< CSI >83;40100;0c' : 'DA2 Response: could be GNU Screen 4.1.0',
     '< CSI >85;95;c'     : 'DA2 Response: could be rxvt-unicode',
+    '< CSI >85;95;0c'    : 'DA2 Response: could be rxvt-unicode or tty.js(rxvt-unicode mode)',
     '< CSI $y'           : 'DECRPM / DECRQM response, report ANSI mode',
     '< CSI ?$y'          : 'DECRPM / DECRQM response, report DEC private mode',
     '< CSI 1t'           : 'CSI 11 t Response: window is open',
@@ -206,6 +210,11 @@ _SEQDB = {
     '< CSI 21~'          : 'F10 key (xterm)',
     '< CSI 23~'          : 'F11 key (xterm)',
     '< CSI 24~'          : 'F12 key (xterm)',
+    '< CSI 8850~'        : 'SKK mode report: hankaku mode (sentimental-skk)',
+    '< CSI 8851~'        : 'SKK mode report: zenkaku mode (sentimental-skk)',
+    '< CSI 8852~'        : 'SKK mode report: hiragana mode (sentimental-skk)',
+    '< CSI 8853~'        : 'SKK mode report: katakana mode (sentimental-skk)',
+    '< CSI 8854~'        : 'SKK mode report: abbrev mode (sentimental-skk)',
     '< CSI 1;2P'         : 'Shift + F1 key (xterm)',
     '< CSI 1;2Q'         : 'Shift + F2 key (xterm)',
     '< CSI 1;2R'         : 'Shift + F3 key (xterm)',
@@ -515,6 +524,9 @@ _SEQDB = {
     '> CSI ?7700h'       : 'DECSET 7700 / enable ambiguous reporting(MinTTY)',
     '> CSI ?8428h'       : 'DECSET 8428 / treat ambiguous characters as narrow(RLogin)',
     '> CSI ?8441h'       : 'DECSET 8441 / IME open(RLogin)',
+    '> CSI ?8448h'       : 'DECSET 8448 / disable Unicode Normalization (RLogin)',
+    '> CSI ?8800h'       : 'DECSET 8800 / enable DRCS-unicode mapping (drcsterm)',
+    '> CSI ?8840h'       : 'DECSET 8840 / treat ambiguous characters as wide (tanasinn)',
     '> CSI i'            : 'MC',
     '> CSI ?i'           : 'MC - DEC Specific',
     '> CSI l'            : 'RM',
@@ -568,6 +580,9 @@ _SEQDB = {
     '> CSI ?7700l'       : 'DECRST 7700 / disable ambiguous reporting (MinTTY)',
     '> CSI ?8428l'       : 'DECRST 8428 / treat ambiguous characters as wide(RLogin)',
     '> CSI ?8441l'       : 'DECRST 8441 / IME close(RLogin)',
+    '> CSI ?8448l'       : 'DECRST 8448 / enable Unicode Normalization (RLogin)',
+    '> CSI ?8800l'       : 'DECRST 8800 / disable DRCS-unicode mapping (drcsterm)',
+    '> CSI ?8840l'       : 'DECRST 8840 / treat ambiguous characters as narrow (tanasinn)',
     '> CSI m'            : 'SGR / select graphics rendition',
     '> CSI 0m'           : 'SGR 0 / reset attributes',
     '> CSI 00m'          : 'SGR 0 / reset attributes',
